# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from ....requests.read_v1request import ReadV1RequestParams
from ....types.read_v1response import ReadV1Response
from .raw_client import AsyncRawTextClient, RawTextClient
from .types.text_analyze_request_callback_method import TextAnalyzeRequestCallbackMethod
from .types.text_analyze_request_custom_intent_mode import TextAnalyzeRequestCustomIntentMode
from .types.text_analyze_request_custom_topic_mode import TextAnalyzeRequestCustomTopicMode
from .types.text_analyze_request_summarize import TextAnalyzeRequestSummarize

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TextClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTextClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTextClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTextClient
        """
        return self._raw_client

    def analyze(
        self,
        *,
        request: ReadV1RequestParams,
        callback: typing.Optional[str] = None,
        callback_method: typing.Optional[TextAnalyzeRequestCallbackMethod] = None,
        sentiment: typing.Optional[bool] = None,
        summarize: typing.Optional[TextAnalyzeRequestSummarize] = None,
        tag: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        topics: typing.Optional[bool] = None,
        custom_topic: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        custom_topic_mode: typing.Optional[TextAnalyzeRequestCustomTopicMode] = None,
        intents: typing.Optional[bool] = None,
        custom_intent: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        custom_intent_mode: typing.Optional[TextAnalyzeRequestCustomIntentMode] = None,
        language: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ReadV1Response:
        """
        Analyze text content using Deepgrams text analysis API

        Parameters
        ----------
        request : ReadV1RequestParams

        callback : typing.Optional[str]
            URL to which we'll make the callback request

        callback_method : typing.Optional[TextAnalyzeRequestCallbackMethod]
            HTTP method by which the callback request will be made

        sentiment : typing.Optional[bool]
            Recognizes the sentiment throughout a transcript or text

        summarize : typing.Optional[TextAnalyzeRequestSummarize]
            Summarize content. For Listen API, supports string version option. For Read API, accepts boolean only.

        tag : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Label your requests for the purpose of identification during usage reporting

        topics : typing.Optional[bool]
            Detect topics throughout a transcript or text

        custom_topic : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Custom topics you want the model to detect within your input audio or text if present Submit up to `100`.

        custom_topic_mode : typing.Optional[TextAnalyzeRequestCustomTopicMode]
            Sets how the model will interpret strings submitted to the `custom_topic` param. When `strict`, the model will only return topics submitted using the `custom_topic` param. When `extended`, the model will return its own detected topics in addition to those submitted using the `custom_topic` param

        intents : typing.Optional[bool]
            Recognizes speaker intent throughout a transcript or text

        custom_intent : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Custom intents you want the model to detect within your input audio if present

        custom_intent_mode : typing.Optional[TextAnalyzeRequestCustomIntentMode]
            Sets how the model will interpret intents submitted to the `custom_intent` param. When `strict`, the model will only return intents submitted using the `custom_intent` param. When `extended`, the model will return its own detected intents in the `custom_intent` param.

        language : typing.Optional[str]
            The [BCP-47 language tag](https://tools.ietf.org/html/bcp47) that hints at the primary spoken language. Depending on the Model and API endpoint you choose only certain languages are available

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ReadV1Response
            Successful text analysis

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.read.v1.text.analyze(
            callback="callback",
            callback_method="POST",
            sentiment=True,
            summarize="v2",
            tag="tag",
            topics=True,
            custom_topic="custom_topic",
            custom_topic_mode="extended",
            intents=True,
            custom_intent="custom_intent",
            custom_intent_mode="extended",
            language="language",
            request={"url": "url"},
        )
        """
        _response = self._raw_client.analyze(
            request=request,
            callback=callback,
            callback_method=callback_method,
            sentiment=sentiment,
            summarize=summarize,
            tag=tag,
            topics=topics,
            custom_topic=custom_topic,
            custom_topic_mode=custom_topic_mode,
            intents=intents,
            custom_intent=custom_intent,
            custom_intent_mode=custom_intent_mode,
            language=language,
            request_options=request_options,
        )
        return _response.data


class AsyncTextClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTextClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTextClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTextClient
        """
        return self._raw_client

    async def analyze(
        self,
        *,
        request: ReadV1RequestParams,
        callback: typing.Optional[str] = None,
        callback_method: typing.Optional[TextAnalyzeRequestCallbackMethod] = None,
        sentiment: typing.Optional[bool] = None,
        summarize: typing.Optional[TextAnalyzeRequestSummarize] = None,
        tag: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        topics: typing.Optional[bool] = None,
        custom_topic: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        custom_topic_mode: typing.Optional[TextAnalyzeRequestCustomTopicMode] = None,
        intents: typing.Optional[bool] = None,
        custom_intent: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        custom_intent_mode: typing.Optional[TextAnalyzeRequestCustomIntentMode] = None,
        language: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ReadV1Response:
        """
        Analyze text content using Deepgrams text analysis API

        Parameters
        ----------
        request : ReadV1RequestParams

        callback : typing.Optional[str]
            URL to which we'll make the callback request

        callback_method : typing.Optional[TextAnalyzeRequestCallbackMethod]
            HTTP method by which the callback request will be made

        sentiment : typing.Optional[bool]
            Recognizes the sentiment throughout a transcript or text

        summarize : typing.Optional[TextAnalyzeRequestSummarize]
            Summarize content. For Listen API, supports string version option. For Read API, accepts boolean only.

        tag : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Label your requests for the purpose of identification during usage reporting

        topics : typing.Optional[bool]
            Detect topics throughout a transcript or text

        custom_topic : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Custom topics you want the model to detect within your input audio or text if present Submit up to `100`.

        custom_topic_mode : typing.Optional[TextAnalyzeRequestCustomTopicMode]
            Sets how the model will interpret strings submitted to the `custom_topic` param. When `strict`, the model will only return topics submitted using the `custom_topic` param. When `extended`, the model will return its own detected topics in addition to those submitted using the `custom_topic` param

        intents : typing.Optional[bool]
            Recognizes speaker intent throughout a transcript or text

        custom_intent : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Custom intents you want the model to detect within your input audio if present

        custom_intent_mode : typing.Optional[TextAnalyzeRequestCustomIntentMode]
            Sets how the model will interpret intents submitted to the `custom_intent` param. When `strict`, the model will only return intents submitted using the `custom_intent` param. When `extended`, the model will return its own detected intents in the `custom_intent` param.

        language : typing.Optional[str]
            The [BCP-47 language tag](https://tools.ietf.org/html/bcp47) that hints at the primary spoken language. Depending on the Model and API endpoint you choose only certain languages are available

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ReadV1Response
            Successful text analysis

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.read.v1.text.analyze(
                callback="callback",
                callback_method="POST",
                sentiment=True,
                summarize="v2",
                tag="tag",
                topics=True,
                custom_topic="custom_topic",
                custom_topic_mode="extended",
                intents=True,
                custom_intent="custom_intent",
                custom_intent_mode="extended",
                language="language",
                request={"url": "url"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.analyze(
            request=request,
            callback=callback,
            callback_method=callback_method,
            sentiment=sentiment,
            summarize=summarize,
            tag=tag,
            topics=topics,
            custom_topic=custom_topic,
            custom_topic_mode=custom_topic_mode,
            intents=intents,
            custom_intent=custom_intent,
            custom_intent_mode=custom_intent_mode,
            language=language,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .get_project_key_v1response_item import GetProjectKeyV1ResponseItemParams


class GetProjectKeyV1ResponseParams(typing_extensions.TypedDict):
    item: typing_extensions.NotRequired[GetProjectKeyV1ResponseItemParams]



# This file was auto-generated by Fern from our API Definition.

import typing

MediaTranscribeRequestEncoding = typing.Union[
    typing.Literal["linear16", "flac", "mulaw", "amr-nb", "amr-wb", "opus", "speex", "g729"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .....types.listen_v1accepted_response import ListenV1AcceptedResponse
from .....types.listen_v1response import ListenV1Response

MediaTranscribeResponse = typing.Union[ListenV1Response, ListenV1AcceptedResponse]



# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from ....types.get_model_v1response import GetModelV1Response
from ....types.list_models_v1response import ListModelsV1Response
from .raw_client import AsyncRawModelsClient, RawModelsClient


class ModelsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawModelsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawModelsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawModelsClient
        """
        return self._raw_client

    def list(
        self, *, include_outdated: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> ListModelsV1Response:
        """
        Returns metadata on all the latest public models. To retrieve custom models, use Get Project Models.

        Parameters
        ----------
        include_outdated : typing.Optional[bool]
            returns non-latest versions of models

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListModelsV1Response
            A list of models

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.models.list(
            include_outdated=True,
        )
        """
        _response = self._raw_client.list(include_outdated=include_outdated, request_options=request_options)
        return _response.data

    def get(self, model_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> GetModelV1Response:
        """
        Returns metadata for a specific public model

        Parameters
        ----------
        model_id : str
            The specific UUID of the model

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetModelV1Response
            A model object that can be either STT or TTS

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.models.get(
            model_id="af6e9977-99f6-4d8f-b6f5-dfdf6fb6e291",
        )
        """
        _response = self._raw_client.get(model_id, request_options=request_options)
        return _response.data


class AsyncModelsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawModelsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawModelsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawModelsClient
        """
        return self._raw_client

    async def list(
        self, *, include_outdated: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> ListModelsV1Response:
        """
        Returns metadata on all the latest public models. To retrieve custom models, use Get Project Models.

        Parameters
        ----------
        include_outdated : typing.Optional[bool]
            returns non-latest versions of models

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListModelsV1Response
            A list of models

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.models.list(
                include_outdated=True,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(include_outdated=include_outdated, request_options=request_options)
        return _response.data

    async def get(
        self, model_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetModelV1Response:
        """
        Returns metadata for a specific public model

        Parameters
        ----------
        model_id : str
            The specific UUID of the model

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetModelV1Response
            A model object that can be either STT or TTS

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.models.get(
                model_id="af6e9977-99f6-4d8f-b6f5-dfdf6fb6e291",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(model_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class GetModelV1ResponseMetadataMetadataParams(typing_extensions.TypedDict):
    accent: typing_extensions.NotRequired[str]
    age: typing_extensions.NotRequired[str]
    color: typing_extensions.NotRequired[str]
    image: typing_extensions.NotRequired[str]
    sample: typing_extensions.NotRequired[str]
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    use_cases: typing_extensions.NotRequired[typing.Sequence[str]]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ......core.api_error import ApiError
from ......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ......core.http_response import AsyncHttpResponse, HttpResponse
from ......core.jsonable_encoder import jsonable_encoder
from ......core.pydantic_utilities import parse_obj_as
from ......core.request_options import RequestOptions
from ......errors.bad_request_error import BadRequestError
from ......types.list_billing_fields_v1response import ListBillingFieldsV1Response


class RawFieldsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ListBillingFieldsV1Response]:
        """
        Lists the accessors, deployment types, tags, and line items used for billing data in the specified time period. Use this endpoint if you want to filter your results from the Billing Breakdown endpoint and want to know what filters are available.

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ListBillingFieldsV1Response]
            A list of billing fields for a specific project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/billing/fields",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListBillingFieldsV1Response,
                    parse_obj_as(
                        type_=ListBillingFieldsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawFieldsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ListBillingFieldsV1Response]:
        """
        Lists the accessors, deployment types, tags, and line items used for billing data in the specified time period. Use this endpoint if you want to filter your results from the Billing Breakdown endpoint and want to know what filters are available.

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ListBillingFieldsV1Response]
            A list of billing fields for a specific project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/billing/fields",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListBillingFieldsV1Response,
                    parse_obj_as(
                        type_=ListBillingFieldsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .usage_breakdown_v1response_results_item_grouping import UsageBreakdownV1ResponseResultsItemGroupingParams


class UsageBreakdownV1ResponseResultsItemParams(typing_extensions.TypedDict):
    hours: float
    """
    Audio hours processed
    """

    total_hours: float
    """
    Total hours including all processing
    """

    agent_hours: float
    """
    Agent hours used
    """

    tokens_in: float
    """
    Number of input tokens
    """

    tokens_out: float
    """
    Number of output tokens
    """

    tts_characters: float
    """
    Number of text-to-speech characters processed
    """

    requests: float
    """
    Number of requests
    """

    grouping: UsageBreakdownV1ResponseResultsItemGroupingParams



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .shared_intents_results_intents_segments_item_intents_item import (
    SharedIntentsResultsIntentsSegmentsItemIntentsItemParams,
)


class SharedIntentsResultsIntentsSegmentsItemParams(typing_extensions.TypedDict):
    text: typing_extensions.NotRequired[str]
    start_word: typing_extensions.NotRequired[float]
    end_word: typing_extensions.NotRequired[float]
    intents: typing_extensions.NotRequired[typing.Sequence[SharedIntentsResultsIntentsSegmentsItemIntentsItemParams]]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_results_summary_results_summary import ReadV1ResponseResultsSummaryResultsSummaryParams


class ReadV1ResponseResultsSummaryResultsParams(typing_extensions.TypedDict):
    summary: typing_extensions.NotRequired[ReadV1ResponseResultsSummaryResultsSummaryParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .project_request_response import ProjectRequestResponseParams


class ListProjectRequestsV1ResponseParams(typing_extensions.TypedDict):
    page: typing_extensions.NotRequired[float]
    """
    The page number of the paginated response
    """

    limit: typing_extensions.NotRequired[float]
    """
    The number of results per page
    """

    requests: typing_extensions.NotRequired[typing.Sequence[ProjectRequestResponseParams]]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class BillingBreakdownV1ResponseResultsItemGroupingParams(typing_extensions.TypedDict):
    start: typing_extensions.NotRequired[str]
    """
    Start date for this group
    """

    end: typing_extensions.NotRequired[str]
    """
    End date for this group
    """

    accessor: typing_extensions.NotRequired[str]
    """
    Optional accessor identifier, null unless grouped by accessor.
    """

    deployment: typing_extensions.NotRequired[str]
    """
    Optional deployment identifier, null unless grouped by deployment.
    """

    line_item: typing_extensions.NotRequired[str]
    """
    Optional line item identifier, null unless grouped by line item.
    """

    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Optional list of tags, null unless grouped by tags.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResultsEntitiesItemParams(typing_extensions.TypedDict):
    label: str
    """
    The type/category of the entity (e.g., NAME, PHONE_NUMBER, EMAIL_ADDRESS, ORGANIZATION, CARDINAL)
    """

    value: str
    """
    The formatted text representation of the entity
    """

    raw_value: str
    """
    The original spoken text of the entity (present when formatting is enabled)
    """

    confidence: float
    """
    The confidence score of the entity detection
    """

    start_word: int
    """
    The index of the first word of the entity in the transcript (inclusive)
    """

    end_word: int
    """
    The index of the last word of the entity in the transcript (exclusive)
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentV1AgentStartedSpeaking(UniversalBaseModel):
    type: typing.Literal["AgentStartedSpeaking"] = pydantic.Field(default="AgentStartedSpeaking")
    """
    Message type identifier for agent started speaking
    """

    total_latency: float = pydantic.Field()
    """
    Seconds from receiving the user's utterance to producing the agent's reply
    """

    tts_latency: float = pydantic.Field()
    """
    The portion of total latency attributable to text-to-speech
    """

    ttt_latency: float = pydantic.Field()
    """
    The portion of total latency attributable to text-to-text (usually an LLM)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ......core.request_options import RequestOptions
from ......types.create_project_invite_v1response import CreateProjectInviteV1Response
from ......types.delete_project_invite_v1response import DeleteProjectInviteV1Response
from ......types.list_project_invites_v1response import ListProjectInvitesV1Response
from .raw_client import AsyncRawInvitesClient, RawInvitesClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class InvitesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawInvitesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawInvitesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawInvitesClient
        """
        return self._raw_client

    def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ListProjectInvitesV1Response:
        """
        Generates a list of invites for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectInvitesV1Response
            A list of invites for a specific project

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.members.invites.list(
            project_id="123456-7890-1234-5678-901234",
        )
        """
        _response = self._raw_client.list(project_id, request_options=request_options)
        return _response.data

    def create(
        self, project_id: str, *, email: str, scope: str, request_options: typing.Optional[RequestOptions] = None
    ) -> CreateProjectInviteV1Response:
        """
        Generates an invite for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        email : str
            The email address of the invitee

        scope : str
            The scope of the invitee

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateProjectInviteV1Response
            The invite was successfully generated

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.members.invites.create(
            project_id="123456-7890-1234-5678-901234",
            email="email",
            scope="scope",
        )
        """
        _response = self._raw_client.create(project_id, email=email, scope=scope, request_options=request_options)
        return _response.data

    def delete(
        self, project_id: str, email: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteProjectInviteV1Response:
        """
        Deletes an invite for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        email : str
            The email address of the member

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectInviteV1Response
            The invite was successfully deleted

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.members.invites.delete(
            project_id="123456-7890-1234-5678-901234",
            email="john.doe@example.com",
        )
        """
        _response = self._raw_client.delete(project_id, email, request_options=request_options)
        return _response.data


class AsyncInvitesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawInvitesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawInvitesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawInvitesClient
        """
        return self._raw_client

    async def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ListProjectInvitesV1Response:
        """
        Generates a list of invites for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectInvitesV1Response
            A list of invites for a specific project

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.members.invites.list(
                project_id="123456-7890-1234-5678-901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(project_id, request_options=request_options)
        return _response.data

    async def create(
        self, project_id: str, *, email: str, scope: str, request_options: typing.Optional[RequestOptions] = None
    ) -> CreateProjectInviteV1Response:
        """
        Generates an invite for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        email : str
            The email address of the invitee

        scope : str
            The scope of the invitee

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateProjectInviteV1Response
            The invite was successfully generated

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.members.invites.create(
                project_id="123456-7890-1234-5678-901234",
                email="email",
                scope="scope",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(project_id, email=email, scope=scope, request_options=request_options)
        return _response.data

    async def delete(
        self, project_id: str, email: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteProjectInviteV1Response:
        """
        Deletes an invite for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        email : str
            The email address of the member

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectInviteV1Response
            The invite was successfully deleted

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.members.invites.delete(
                project_id="123456-7890-1234-5678-901234",
                email="john.doe@example.com",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(project_id, email, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .shared_topics_results_topics import SharedTopicsResultsTopicsParams


class SharedTopicsResultsParams(typing_extensions.TypedDict):
    topics: typing_extensions.NotRequired[SharedTopicsResultsTopicsParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1settings_audio_input import AgentV1SettingsAudioInput
from .agent_v1settings_audio_output import AgentV1SettingsAudioOutput


class AgentV1SettingsAudio(UniversalBaseModel):
    input: typing.Optional[AgentV1SettingsAudioInput] = pydantic.Field(default=None)
    """
    Audio input configuration settings. If omitted, defaults to encoding=linear16 and sample_rate=24000. Higher sample rates like 44100 Hz provide better audio quality.
    """

    output: typing.Optional[AgentV1SettingsAudioOutput] = pydantic.Field(default=None)
    """
    Audio output configuration settings
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ReadV1RequestUrlParams(typing_extensions.TypedDict):
    url: str
    """
    A URL pointing to the text source
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UsageBreakdownV1ResponseResultsItemGrouping(UniversalBaseModel):
    start: typing.Optional[str] = pydantic.Field(default=None)
    """
    Start date for this group
    """

    end: typing.Optional[str] = pydantic.Field(default=None)
    """
    End date for this group
    """

    accessor: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional accessor identifier
    """

    endpoint: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional endpoint identifier
    """

    feature_set: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional feature set identifier
    """

    models: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional models identifier
    """

    method: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional method identifier
    """

    tags: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional tags
    """

    deployment: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional deployment identifier
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .aws_bedrock_think_provider_credentials_type import AwsBedrockThinkProviderCredentialsType


class AwsBedrockThinkProviderCredentials(UniversalBaseModel):
    """
    AWS credentials type (STS short-lived or IAM long-lived)
    """

    type: typing.Optional[AwsBedrockThinkProviderCredentialsType] = pydantic.Field(default=None)
    """
    AWS credentials type (STS short-lived or IAM long-lived)
    """

    region: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS region
    """

    access_key_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS access key
    """

    secret_access_key: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS secret access key
    """

    session_token: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS session token (required for STS only)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .agent_v1agent_audio_done import AgentV1AgentAudioDoneParams
    from .agent_v1agent_started_speaking import AgentV1AgentStartedSpeakingParams
    from .agent_v1agent_thinking import AgentV1AgentThinkingParams
    from .agent_v1conversation_text import AgentV1ConversationTextParams
    from .agent_v1error import AgentV1ErrorParams
    from .agent_v1function_call_request import AgentV1FunctionCallRequestParams
    from .agent_v1function_call_request_functions_item import AgentV1FunctionCallRequestFunctionsItemParams
    from .agent_v1inject_agent_message import AgentV1InjectAgentMessageParams
    from .agent_v1inject_user_message import AgentV1InjectUserMessageParams
    from .agent_v1injection_refused import AgentV1InjectionRefusedParams
    from .agent_v1keep_alive import AgentV1KeepAliveParams
    from .agent_v1prompt_updated import AgentV1PromptUpdatedParams
    from .agent_v1receive_function_call_response import AgentV1ReceiveFunctionCallResponseParams
    from .agent_v1send_function_call_response import AgentV1SendFunctionCallResponseParams
    from .agent_v1settings import AgentV1SettingsParams
    from .agent_v1settings_agent import AgentV1SettingsAgentParams
    from .agent_v1settings_agent_context import AgentV1SettingsAgentContextParams
    from .agent_v1settings_agent_context_messages_item import AgentV1SettingsAgentContextMessagesItemParams
    from .agent_v1settings_agent_context_messages_item_content import (
        AgentV1SettingsAgentContextMessagesItemContentParams,
    )
    from .agent_v1settings_agent_context_messages_item_function_calls import (
        AgentV1SettingsAgentContextMessagesItemFunctionCallsParams,
    )
    from .agent_v1settings_agent_context_messages_item_function_calls_function_calls_item import (
        AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams,
    )
    from .agent_v1settings_agent_listen import AgentV1SettingsAgentListenParams
    from .agent_v1settings_agent_listen_provider import (
        AgentV1SettingsAgentListenProviderParams,
        AgentV1SettingsAgentListenProvider_V1Params,
        AgentV1SettingsAgentListenProvider_V2Params,
    )
    from .agent_v1settings_agent_listen_provider_v1 import AgentV1SettingsAgentListenProviderV1Params
    from .agent_v1settings_agent_listen_provider_v2 import AgentV1SettingsAgentListenProviderV2Params
    from .agent_v1settings_agent_speak import AgentV1SettingsAgentSpeakParams
    from .agent_v1settings_agent_think import AgentV1SettingsAgentThinkParams
    from .agent_v1settings_applied import AgentV1SettingsAppliedParams
    from .agent_v1settings_audio import AgentV1SettingsAudioParams
    from .agent_v1settings_audio_input import AgentV1SettingsAudioInputParams
    from .agent_v1settings_audio_output import AgentV1SettingsAudioOutputParams
    from .agent_v1settings_flags import AgentV1SettingsFlagsParams
    from .agent_v1speak_updated import AgentV1SpeakUpdatedParams
    from .agent_v1update_prompt import AgentV1UpdatePromptParams
    from .agent_v1update_speak import AgentV1UpdateSpeakParams
    from .agent_v1user_started_speaking import AgentV1UserStartedSpeakingParams
    from .agent_v1warning import AgentV1WarningParams
    from .agent_v1welcome import AgentV1WelcomeParams
_dynamic_imports: typing.Dict[str, str] = {
    "AgentV1AgentAudioDoneParams": ".agent_v1agent_audio_done",
    "AgentV1AgentStartedSpeakingParams": ".agent_v1agent_started_speaking",
    "AgentV1AgentThinkingParams": ".agent_v1agent_thinking",
    "AgentV1ConversationTextParams": ".agent_v1conversation_text",
    "AgentV1ErrorParams": ".agent_v1error",
    "AgentV1FunctionCallRequestFunctionsItemParams": ".agent_v1function_call_request_functions_item",
    "AgentV1FunctionCallRequestParams": ".agent_v1function_call_request",
    "AgentV1InjectAgentMessageParams": ".agent_v1inject_agent_message",
    "AgentV1InjectUserMessageParams": ".agent_v1inject_user_message",
    "AgentV1InjectionRefusedParams": ".agent_v1injection_refused",
    "AgentV1KeepAliveParams": ".agent_v1keep_alive",
    "AgentV1PromptUpdatedParams": ".agent_v1prompt_updated",
    "AgentV1ReceiveFunctionCallResponseParams": ".agent_v1receive_function_call_response",
    "AgentV1SendFunctionCallResponseParams": ".agent_v1send_function_call_response",
    "AgentV1SettingsAgentContextMessagesItemContentParams": ".agent_v1settings_agent_context_messages_item_content",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams": ".agent_v1settings_agent_context_messages_item_function_calls_function_calls_item",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsParams": ".agent_v1settings_agent_context_messages_item_function_calls",
    "AgentV1SettingsAgentContextMessagesItemParams": ".agent_v1settings_agent_context_messages_item",
    "AgentV1SettingsAgentContextParams": ".agent_v1settings_agent_context",
    "AgentV1SettingsAgentListenParams": ".agent_v1settings_agent_listen",
    "AgentV1SettingsAgentListenProviderParams": ".agent_v1settings_agent_listen_provider",
    "AgentV1SettingsAgentListenProviderV1Params": ".agent_v1settings_agent_listen_provider_v1",
    "AgentV1SettingsAgentListenProviderV2Params": ".agent_v1settings_agent_listen_provider_v2",
    "AgentV1SettingsAgentListenProvider_V1Params": ".agent_v1settings_agent_listen_provider",
    "AgentV1SettingsAgentListenProvider_V2Params": ".agent_v1settings_agent_listen_provider",
    "AgentV1SettingsAgentParams": ".agent_v1settings_agent",
    "AgentV1SettingsAgentSpeakParams": ".agent_v1settings_agent_speak",
    "AgentV1SettingsAgentThinkParams": ".agent_v1settings_agent_think",
    "AgentV1SettingsAppliedParams": ".agent_v1settings_applied",
    "AgentV1SettingsAudioInputParams": ".agent_v1settings_audio_input",
    "AgentV1SettingsAudioOutputParams": ".agent_v1settings_audio_output",
    "AgentV1SettingsAudioParams": ".agent_v1settings_audio",
    "AgentV1SettingsFlagsParams": ".agent_v1settings_flags",
    "AgentV1SettingsParams": ".agent_v1settings",
    "AgentV1SpeakUpdatedParams": ".agent_v1speak_updated",
    "AgentV1UpdatePromptParams": ".agent_v1update_prompt",
    "AgentV1UpdateSpeakParams": ".agent_v1update_speak",
    "AgentV1UserStartedSpeakingParams": ".agent_v1user_started_speaking",
    "AgentV1WarningParams": ".agent_v1warning",
    "AgentV1WelcomeParams": ".agent_v1welcome",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentV1AgentAudioDoneParams",
    "AgentV1AgentStartedSpeakingParams",
    "AgentV1AgentThinkingParams",
    "AgentV1ConversationTextParams",
    "AgentV1ErrorParams",
    "AgentV1FunctionCallRequestFunctionsItemParams",
    "AgentV1FunctionCallRequestParams",
    "AgentV1InjectAgentMessageParams",
    "AgentV1InjectUserMessageParams",
    "AgentV1InjectionRefusedParams",
    "AgentV1KeepAliveParams",
    "AgentV1PromptUpdatedParams",
    "AgentV1ReceiveFunctionCallResponseParams",
    "AgentV1SendFunctionCallResponseParams",
    "AgentV1SettingsAgentContextMessagesItemContentParams",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsParams",
    "AgentV1SettingsAgentContextMessagesItemParams",
    "AgentV1SettingsAgentContextParams",
    "AgentV1SettingsAgentListenParams",
    "AgentV1SettingsAgentListenProviderParams",
    "AgentV1SettingsAgentListenProviderV1Params",
    "AgentV1SettingsAgentListenProviderV2Params",
    "AgentV1SettingsAgentListenProvider_V1Params",
    "AgentV1SettingsAgentListenProvider_V2Params",
    "AgentV1SettingsAgentParams",
    "AgentV1SettingsAgentSpeakParams",
    "AgentV1SettingsAgentThinkParams",
    "AgentV1SettingsAppliedParams",
    "AgentV1SettingsAudioInputParams",
    "AgentV1SettingsAudioOutputParams",
    "AgentV1SettingsAudioParams",
    "AgentV1SettingsFlagsParams",
    "AgentV1SettingsParams",
    "AgentV1SpeakUpdatedParams",
    "AgentV1UpdatePromptParams",
    "AgentV1UpdateSpeakParams",
    "AgentV1UserStartedSpeakingParams",
    "AgentV1WarningParams",
    "AgentV1WelcomeParams",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .aws_polly_speak_provider_credentials import AwsPollySpeakProviderCredentials
from .aws_polly_speak_provider_engine import AwsPollySpeakProviderEngine
from .aws_polly_speak_provider_voice import AwsPollySpeakProviderVoice
from .cartesia_speak_provider_model_id import CartesiaSpeakProviderModelId
from .cartesia_speak_provider_voice import CartesiaSpeakProviderVoice
from .deepgram_speak_provider_model import DeepgramSpeakProviderModel
from .eleven_labs_speak_provider_model_id import ElevenLabsSpeakProviderModelId
from .open_ai_speak_provider_model import OpenAiSpeakProviderModel
from .open_ai_speak_provider_voice import OpenAiSpeakProviderVoice


class SpeakSettingsV1Provider_Deepgram(UniversalBaseModel):
    type: typing.Literal["deepgram"] = "deepgram"
    version: typing.Optional[typing.Literal["v1"]] = None
    model: DeepgramSpeakProviderModel

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class SpeakSettingsV1Provider_ElevenLabs(UniversalBaseModel):
    type: typing.Literal["eleven_labs"] = "eleven_labs"
    version: typing.Optional[typing.Literal["v1"]] = None
    model_id: ElevenLabsSpeakProviderModelId
    language: typing.Optional[str] = None
    language_code: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class SpeakSettingsV1Provider_Cartesia(UniversalBaseModel):
    type: typing.Literal["cartesia"] = "cartesia"
    version: typing.Optional[typing.Literal["2025-03-17"]] = None
    model_id: CartesiaSpeakProviderModelId
    voice: CartesiaSpeakProviderVoice
    language: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class SpeakSettingsV1Provider_OpenAi(UniversalBaseModel):
    type: typing.Literal["open_ai"] = "open_ai"
    version: typing.Optional[typing.Literal["v1"]] = None
    model: OpenAiSpeakProviderModel
    voice: OpenAiSpeakProviderVoice

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class SpeakSettingsV1Provider_AwsPolly(UniversalBaseModel):
    type: typing.Literal["aws_polly"] = "aws_polly"
    voice: AwsPollySpeakProviderVoice
    language: str
    language_code: typing.Optional[str] = None
    engine: AwsPollySpeakProviderEngine
    credentials: AwsPollySpeakProviderCredentials

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


SpeakSettingsV1Provider = typing_extensions.Annotated[
    typing.Union[
        SpeakSettingsV1Provider_Deepgram,
        SpeakSettingsV1Provider_ElevenLabs,
        SpeakSettingsV1Provider_Cartesia,
        SpeakSettingsV1Provider_OpenAi,
        SpeakSettingsV1Provider_AwsPolly,
    ],
    pydantic.Field(discriminator="type"),
]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1AgentThinkingParams(typing_extensions.TypedDict):
    type: typing.Literal["AgentThinking"]
    """
    Message type identifier for agent thinking
    """

    content: str
    """
    The text of the agent's thought process
    """



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ......core.api_error import ApiError
from ......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ......core.http_response import AsyncHttpResponse, HttpResponse
from ......core.jsonable_encoder import jsonable_encoder
from ......core.pydantic_utilities import parse_obj_as
from ......core.request_options import RequestOptions
from ......errors.bad_request_error import BadRequestError
from ......types.billing_breakdown_v1response import BillingBreakdownV1Response
from .types.breakdown_list_request_deployment import BreakdownListRequestDeployment
from .types.breakdown_list_request_grouping_item import BreakdownListRequestGroupingItem


class RawBreakdownClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        accessor: typing.Optional[str] = None,
        deployment: typing.Optional[BreakdownListRequestDeployment] = None,
        tag: typing.Optional[str] = None,
        line_item: typing.Optional[str] = None,
        grouping: typing.Optional[
            typing.Union[BreakdownListRequestGroupingItem, typing.Sequence[BreakdownListRequestGroupingItem]]
        ] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[BillingBreakdownV1Response]:
        """
        Retrieves the billing summary for a specific project, with various filter options or by grouping options.

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        accessor : typing.Optional[str]
            Filter for requests where a specific accessor was used

        deployment : typing.Optional[BreakdownListRequestDeployment]
            Filter for requests where a specific deployment was used

        tag : typing.Optional[str]
            Filter for requests where a specific tag was used

        line_item : typing.Optional[str]
            Filter requests by line item (e.g. streaming::nova-3)

        grouping : typing.Optional[typing.Union[BreakdownListRequestGroupingItem, typing.Sequence[BreakdownListRequestGroupingItem]]]
            Group billing breakdown by one or more dimensions (accessor, deployment, line_item, tags)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[BillingBreakdownV1Response]
            Billing breakdown response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/billing/breakdown",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
                "accessor": accessor,
                "deployment": deployment,
                "tag": tag,
                "line_item": line_item,
                "grouping": grouping,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    BillingBreakdownV1Response,
                    parse_obj_as(
                        type_=BillingBreakdownV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawBreakdownClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        accessor: typing.Optional[str] = None,
        deployment: typing.Optional[BreakdownListRequestDeployment] = None,
        tag: typing.Optional[str] = None,
        line_item: typing.Optional[str] = None,
        grouping: typing.Optional[
            typing.Union[BreakdownListRequestGroupingItem, typing.Sequence[BreakdownListRequestGroupingItem]]
        ] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[BillingBreakdownV1Response]:
        """
        Retrieves the billing summary for a specific project, with various filter options or by grouping options.

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        accessor : typing.Optional[str]
            Filter for requests where a specific accessor was used

        deployment : typing.Optional[BreakdownListRequestDeployment]
            Filter for requests where a specific deployment was used

        tag : typing.Optional[str]
            Filter for requests where a specific tag was used

        line_item : typing.Optional[str]
            Filter requests by line item (e.g. streaming::nova-3)

        grouping : typing.Optional[typing.Union[BreakdownListRequestGroupingItem, typing.Sequence[BreakdownListRequestGroupingItem]]]
            Group billing breakdown by one or more dimensions (accessor, deployment, line_item, tags)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[BillingBreakdownV1Response]
            Billing breakdown response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/billing/breakdown",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
                "accessor": accessor,
                "deployment": deployment,
                "tag": tag,
                "line_item": line_item,
                "grouping": grouping,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    BillingBreakdownV1Response,
                    parse_obj_as(
                        type_=BillingBreakdownV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class GetProjectDistributionCredentialsV1ResponseMemberParams(typing_extensions.TypedDict):
    member_id: str
    """
    Unique identifier for the member
    """

    email: str
    """
    Email address of the member
    """



# This file was auto-generated by Fern from our API Definition.

import typing

AwsBedrockThinkProviderModel = typing.Union[
    typing.Literal["anthropic/claude-3-5-sonnet-20240620-v1:0", "anthropic/claude-3-5-haiku-20240307-v1:0"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ....core.api_error import ApiError
from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.http_response import AsyncHttpResponse, HttpResponse
from ....core.jsonable_encoder import jsonable_encoder
from ....core.pydantic_utilities import parse_obj_as
from ....core.request_options import RequestOptions
from ....errors.bad_request_error import BadRequestError
from ....types.create_project_distribution_credentials_v1response import CreateProjectDistributionCredentialsV1Response
from ....types.get_project_distribution_credentials_v1response import GetProjectDistributionCredentialsV1Response
from ....types.list_project_distribution_credentials_v1response import ListProjectDistributionCredentialsV1Response
from .types.distribution_credentials_create_request_scopes_item import DistributionCredentialsCreateRequestScopesItem

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawDistributionCredentialsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ListProjectDistributionCredentialsV1Response]:
        """
        Lists sets of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ListProjectDistributionCredentialsV1Response]
            A list of distribution credentials for a specific project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=ListProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        project_id: str,
        *,
        scopes: typing.Optional[
            typing.Union[
                DistributionCredentialsCreateRequestScopesItem,
                typing.Sequence[DistributionCredentialsCreateRequestScopesItem],
            ]
        ] = None,
        provider: typing.Optional[typing.Literal["quay"]] = None,
        comment: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CreateProjectDistributionCredentialsV1Response]:
        """
        Creates a set of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        scopes : typing.Optional[typing.Union[DistributionCredentialsCreateRequestScopesItem, typing.Sequence[DistributionCredentialsCreateRequestScopesItem]]]
            List of permission scopes for the credentials

        provider : typing.Optional[typing.Literal["quay"]]
            The provider of the distribution service

        comment : typing.Optional[str]
            Optional comment about the credentials

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateProjectDistributionCredentialsV1Response]
            Single distribution credential
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            params={
                "scopes": scopes,
                "provider": provider,
            },
            json={
                "comment": comment,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=CreateProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self,
        project_id: str,
        distribution_credentials_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetProjectDistributionCredentialsV1Response]:
        """
        Returns a set of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        distribution_credentials_id : str
            The UUID of the distribution credentials

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetProjectDistributionCredentialsV1Response]
            Single distribution credential
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials/{jsonable_encoder(distribution_credentials_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=GetProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self,
        project_id: str,
        distribution_credentials_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetProjectDistributionCredentialsV1Response]:
        """
        Deletes a set of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        distribution_credentials_id : str
            The UUID of the distribution credentials

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetProjectDistributionCredentialsV1Response]
            Single distribution credential
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials/{jsonable_encoder(distribution_credentials_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=GetProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawDistributionCredentialsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ListProjectDistributionCredentialsV1Response]:
        """
        Lists sets of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ListProjectDistributionCredentialsV1Response]
            A list of distribution credentials for a specific project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=ListProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        project_id: str,
        *,
        scopes: typing.Optional[
            typing.Union[
                DistributionCredentialsCreateRequestScopesItem,
                typing.Sequence[DistributionCredentialsCreateRequestScopesItem],
            ]
        ] = None,
        provider: typing.Optional[typing.Literal["quay"]] = None,
        comment: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CreateProjectDistributionCredentialsV1Response]:
        """
        Creates a set of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        scopes : typing.Optional[typing.Union[DistributionCredentialsCreateRequestScopesItem, typing.Sequence[DistributionCredentialsCreateRequestScopesItem]]]
            List of permission scopes for the credentials

        provider : typing.Optional[typing.Literal["quay"]]
            The provider of the distribution service

        comment : typing.Optional[str]
            Optional comment about the credentials

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateProjectDistributionCredentialsV1Response]
            Single distribution credential
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            params={
                "scopes": scopes,
                "provider": provider,
            },
            json={
                "comment": comment,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=CreateProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self,
        project_id: str,
        distribution_credentials_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetProjectDistributionCredentialsV1Response]:
        """
        Returns a set of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        distribution_credentials_id : str
            The UUID of the distribution credentials

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetProjectDistributionCredentialsV1Response]
            Single distribution credential
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials/{jsonable_encoder(distribution_credentials_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=GetProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self,
        project_id: str,
        distribution_credentials_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetProjectDistributionCredentialsV1Response]:
        """
        Deletes a set of distribution credentials for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        distribution_credentials_id : str
            The UUID of the distribution credentials

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetProjectDistributionCredentialsV1Response]
            Single distribution credential
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/self-hosted/distribution/credentials/{jsonable_encoder(distribution_credentials_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectDistributionCredentialsV1Response,
                    parse_obj_as(
                        type_=GetProjectDistributionCredentialsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKeyParams


class GetProjectKeyV1ResponseItemMemberParams(typing_extensions.TypedDict):
    member_id: typing_extensions.NotRequired[str]
    email: typing_extensions.NotRequired[str]
    first_name: typing_extensions.NotRequired[str]
    last_name: typing_extensions.NotRequired[str]
    api_key: typing_extensions.NotRequired[GetProjectKeyV1ResponseItemMemberApiKeyParams]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListProjectsV1ResponseProjectsItemParams(typing_extensions.TypedDict):
    project_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the project
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of the project
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentThinkModelsV1ResponseModelsItemIdParams(typing_extensions.TypedDict):
    """
    AWS Bedrock models (custom models accepted)
    """

    id: str
    """
    The unique identifier of the AWS Bedrock model (any model string accepted for BYO LLMs)
    """

    name: str
    """
    The display name of the model
    """

    provider: typing.Literal["aws_bedrock"]
    """
    The provider of the model
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.agent_v1conversation_text_role import AgentV1ConversationTextRole


class AgentV1ConversationTextParams(typing_extensions.TypedDict):
    type: typing.Literal["ConversationText"]
    """
    Message type identifier for conversation text
    """

    role: AgentV1ConversationTextRole
    """
    Identifies who spoke the statement
    """

    content: str
    """
    The actual statement that was spoken
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.speak_settings_v1 import SpeakSettingsV1

AgentV1SettingsAgentSpeak = typing.Union[SpeakSettingsV1, typing.List[SpeakSettingsV1]]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_v1settings_agent_context_messages_item import AgentV1SettingsAgentContextMessagesItemParams


class AgentV1SettingsAgentContextParams(typing_extensions.TypedDict):
    """
    Conversation context including the history of messages and function calls
    """

    messages: typing_extensions.NotRequired[typing.Sequence[AgentV1SettingsAgentContextMessagesItemParams]]
    """
    Conversation history as a list of messages and function calls
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.google_think_provider_model import GoogleThinkProviderModel


class GoogleParams(typing_extensions.TypedDict):
    type: typing.Literal["google"]
    version: typing_extensions.NotRequired[typing.Literal["v1beta"]]
    """
    The REST API version for the Google generative language API
    """

    model: GoogleThinkProviderModel
    """
    Google model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    Google temperature (0-2)
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentV1Warning(UniversalBaseModel):
    """
    Notifies the client of non-fatal errors or warnings
    """

    type: typing.Literal["Warning"] = pydantic.Field(default="Warning")
    """
    Message type identifier for warnings
    """

    description: str = pydantic.Field()
    """
    Description of the warning
    """

    code: str = pydantic.Field()
    """
    Warning code identifier
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1SettingsAgentListenProviderV2Params(typing_extensions.TypedDict):
    type: typing.Literal["deepgram"]
    """
    Provider type for speech-to-text
    """

    model: str
    """
    Model to use for speech to text using the V2 API (e.g. flux-general-en)
    """

    keyterms: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Prompt keyterm recognition to improve Keyword Recall Rate
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.aws_polly_speak_provider_engine import AwsPollySpeakProviderEngine
from ..types.aws_polly_speak_provider_voice import AwsPollySpeakProviderVoice
from .aws_polly_speak_provider_credentials import AwsPollySpeakProviderCredentialsParams


class AwsPollySpeakProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["aws_polly"]
    voice: AwsPollySpeakProviderVoice
    """
    AWS Polly voice name
    """

    language: str
    """
    Language code to use, e.g. 'en-US'. Corresponds to the `language_code` parameter in the AWS Polly API
    """

    language_code: typing_extensions.NotRequired[str]
    """
    Use the `language` field instead.
    """

    engine: AwsPollySpeakProviderEngine
    credentials: AwsPollySpeakProviderCredentialsParams



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ReadV1ResponseResultsSummaryResultsSummaryParams(typing_extensions.TypedDict):
    text: typing_extensions.NotRequired[str]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams(typing_extensions.TypedDict):
    word: typing_extensions.NotRequired[str]
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
    confidence: typing_extensions.NotRequired[float]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.open_ai_speak_provider_model import OpenAiSpeakProviderModel
from ..types.open_ai_speak_provider_voice import OpenAiSpeakProviderVoice


class OpenAiSpeakProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["open_ai"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the OpenAI text-to-speech API
    """

    model: OpenAiSpeakProviderModel
    """
    OpenAI TTS model
    """

    voice: OpenAiSpeakProviderVoice
    """
    OpenAI voice
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .project_request_response import ProjectRequestResponseParams


class GetProjectRequestV1ResponseParams(typing_extensions.TypedDict):
    request: typing_extensions.NotRequired[ProjectRequestResponseParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .open_ai_speak_provider_model import OpenAiSpeakProviderModel
from .open_ai_speak_provider_voice import OpenAiSpeakProviderVoice


class OpenAiSpeakProvider(UniversalBaseModel):
    type: typing.Literal["open_ai"] = "open_ai"
    version: typing.Optional[typing.Literal["v1"]] = pydantic.Field(default=None)
    """
    The REST API version for the OpenAI text-to-speech API
    """

    model: OpenAiSpeakProviderModel = pydantic.Field()
    """
    OpenAI TTS model
    """

    voice: OpenAiSpeakProviderVoice = pydantic.Field()
    """
    OpenAI voice
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class AgentV1FunctionCallRequestFunctionsItemParams(typing_extensions.TypedDict):
    id: str
    """
    Unique identifier for the function call
    """

    name: str
    """
    The name of the function to call
    """

    arguments: str
    """
    JSON string containing the function arguments
    """

    client_side: bool
    """
    Whether the function should be executed client-side
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .agent_v1settings_audio_input import AgentV1SettingsAudioInputParams
from .agent_v1settings_audio_output import AgentV1SettingsAudioOutputParams


class AgentV1SettingsAudioParams(typing_extensions.TypedDict):
    input: typing_extensions.NotRequired[AgentV1SettingsAudioInputParams]
    """
    Audio input configuration settings. If omitted, defaults to encoding=linear16 and sample_rate=24000. Higher sample rates like 44100 Hz provide better audio quality.
    """

    output: typing_extensions.NotRequired[AgentV1SettingsAudioOutputParams]
    """
    Audio output configuration settings
    """



"""
Deepgram Helper Utilities

Custom helper functions and classes for working with Deepgram APIs.
"""

from .text_builder import (
    TextBuilder,
    add_pronunciation,
    ssml_to_deepgram,
    validate_ipa,
    validate_pause,
)

__all__ = [
    "TextBuilder",
    "add_pronunciation",
    "ssml_to_deepgram",
    "validate_ipa",
    "validate_pause",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParams,
)
from .listen_v1response_results_channels_item_search_item import ListenV1ResponseResultsChannelsItemSearchItemParams


class ListenV1ResponseResultsChannelsItemParams(typing_extensions.TypedDict):
    search: typing_extensions.NotRequired[typing.Sequence[ListenV1ResponseResultsChannelsItemSearchItemParams]]
    alternatives: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemParams]
    ]
    detected_language: typing_extensions.NotRequired[str]



# This file was auto-generated by Fern from our API Definition.

import typing

DeepgramSpeakProviderModel = typing.Union[
    typing.Literal[
        "aura-asteria-en",
        "aura-luna-en",
        "aura-stella-en",
        "aura-athena-en",
        "aura-hera-en",
        "aura-orion-en",
        "aura-arcas-en",
        "aura-perseus-en",
        "aura-angus-en",
        "aura-orpheus-en",
        "aura-helios-en",
        "aura-zeus-en",
        "aura-2-amalthea-en",
        "aura-2-andromeda-en",
        "aura-2-apollo-en",
        "aura-2-arcas-en",
        "aura-2-aries-en",
        "aura-2-asteria-en",
        "aura-2-athena-en",
        "aura-2-atlas-en",
        "aura-2-aurora-en",
        "aura-2-callista-en",
        "aura-2-cora-en",
        "aura-2-cordelia-en",
        "aura-2-delia-en",
        "aura-2-draco-en",
        "aura-2-electra-en",
        "aura-2-harmonia-en",
        "aura-2-helena-en",
        "aura-2-hera-en",
        "aura-2-hermes-en",
        "aura-2-hyperion-en",
        "aura-2-iris-en",
        "aura-2-janus-en",
        "aura-2-juno-en",
        "aura-2-jupiter-en",
        "aura-2-luna-en",
        "aura-2-mars-en",
        "aura-2-minerva-en",
        "aura-2-neptune-en",
        "aura-2-odysseus-en",
        "aura-2-ophelia-en",
        "aura-2-orion-en",
        "aura-2-orpheus-en",
        "aura-2-pandora-en",
        "aura-2-phoebe-en",
        "aura-2-pluto-en",
        "aura-2-saturn-en",
        "aura-2-selene-en",
        "aura-2-thalia-en",
        "aura-2-theia-en",
        "aura-2-vesta-en",
        "aura-2-zeus-en",
        "aura-2-sirio-es",
        "aura-2-nestor-es",
        "aura-2-carina-es",
        "aura-2-celeste-es",
        "aura-2-alvaro-es",
        "aura-2-diana-es",
        "aura-2-aquila-es",
        "aura-2-selena-es",
        "aura-2-estrella-es",
        "aura-2-javier-es",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResultsChannelAlternativesItemWordsItemParams(typing_extensions.TypedDict):
    word: str
    """
    The word of the transcription
    """

    start: float
    """
    The start time of the word
    """

    end: float
    """
    The end time of the word
    """

    confidence: float
    """
    The confidence of the word
    """

    language: typing_extensions.NotRequired[str]
    """
    The language of the word
    """

    punctuated_word: typing_extensions.NotRequired[str]
    """
    The punctuated word of the word
    """

    speaker: typing_extensions.NotRequired[float]
    """
    The speaker of the word
    """



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AgentV1AgentAudioDone,
        AgentV1AgentStartedSpeaking,
        AgentV1AgentThinking,
        AgentV1ConversationText,
        AgentV1ConversationTextRole,
        AgentV1Error,
        AgentV1FunctionCallRequest,
        AgentV1FunctionCallRequestFunctionsItem,
        AgentV1InjectAgentMessage,
        AgentV1InjectUserMessage,
        AgentV1InjectionRefused,
        AgentV1KeepAlive,
        AgentV1PromptUpdated,
        AgentV1ReceiveFunctionCallResponse,
        AgentV1SendFunctionCallResponse,
        AgentV1Settings,
        AgentV1SettingsAgent,
        AgentV1SettingsAgentContext,
        AgentV1SettingsAgentContextMessagesItem,
        AgentV1SettingsAgentContextMessagesItemContent,
        AgentV1SettingsAgentContextMessagesItemContentRole,
        AgentV1SettingsAgentContextMessagesItemFunctionCalls,
        AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItem,
        AgentV1SettingsAgentListen,
        AgentV1SettingsAgentListenProvider,
        AgentV1SettingsAgentListenProviderV1,
        AgentV1SettingsAgentListenProviderV2,
        AgentV1SettingsAgentListenProvider_V1,
        AgentV1SettingsAgentListenProvider_V2,
        AgentV1SettingsAgentSpeak,
        AgentV1SettingsAgentThink,
        AgentV1SettingsApplied,
        AgentV1SettingsAudio,
        AgentV1SettingsAudioInput,
        AgentV1SettingsAudioInputEncoding,
        AgentV1SettingsAudioOutput,
        AgentV1SettingsAudioOutputEncoding,
        AgentV1SettingsFlags,
        AgentV1SpeakUpdated,
        AgentV1UpdatePrompt,
        AgentV1UpdateSpeak,
        AgentV1UserStartedSpeaking,
        AgentV1Warning,
        AgentV1Welcome,
    )
    from . import settings
    from .requests import (
        AgentV1AgentAudioDoneParams,
        AgentV1AgentStartedSpeakingParams,
        AgentV1AgentThinkingParams,
        AgentV1ConversationTextParams,
        AgentV1ErrorParams,
        AgentV1FunctionCallRequestFunctionsItemParams,
        AgentV1FunctionCallRequestParams,
        AgentV1InjectAgentMessageParams,
        AgentV1InjectUserMessageParams,
        AgentV1InjectionRefusedParams,
        AgentV1KeepAliveParams,
        AgentV1PromptUpdatedParams,
        AgentV1ReceiveFunctionCallResponseParams,
        AgentV1SendFunctionCallResponseParams,
        AgentV1SettingsAgentContextMessagesItemContentParams,
        AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams,
        AgentV1SettingsAgentContextMessagesItemFunctionCallsParams,
        AgentV1SettingsAgentContextMessagesItemParams,
        AgentV1SettingsAgentContextParams,
        AgentV1SettingsAgentListenParams,
        AgentV1SettingsAgentListenProviderParams,
        AgentV1SettingsAgentListenProviderV1Params,
        AgentV1SettingsAgentListenProviderV2Params,
        AgentV1SettingsAgentListenProvider_V1Params,
        AgentV1SettingsAgentListenProvider_V2Params,
        AgentV1SettingsAgentParams,
        AgentV1SettingsAgentSpeakParams,
        AgentV1SettingsAgentThinkParams,
        AgentV1SettingsAppliedParams,
        AgentV1SettingsAudioInputParams,
        AgentV1SettingsAudioOutputParams,
        AgentV1SettingsAudioParams,
        AgentV1SettingsFlagsParams,
        AgentV1SettingsParams,
        AgentV1SpeakUpdatedParams,
        AgentV1UpdatePromptParams,
        AgentV1UpdateSpeakParams,
        AgentV1UserStartedSpeakingParams,
        AgentV1WarningParams,
        AgentV1WelcomeParams,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AgentV1AgentAudioDone": ".types",
    "AgentV1AgentAudioDoneParams": ".requests",
    "AgentV1AgentStartedSpeaking": ".types",
    "AgentV1AgentStartedSpeakingParams": ".requests",
    "AgentV1AgentThinking": ".types",
    "AgentV1AgentThinkingParams": ".requests",
    "AgentV1ConversationText": ".types",
    "AgentV1ConversationTextParams": ".requests",
    "AgentV1ConversationTextRole": ".types",
    "AgentV1Error": ".types",
    "AgentV1ErrorParams": ".requests",
    "AgentV1FunctionCallRequest": ".types",
    "AgentV1FunctionCallRequestFunctionsItem": ".types",
    "AgentV1FunctionCallRequestFunctionsItemParams": ".requests",
    "AgentV1FunctionCallRequestParams": ".requests",
    "AgentV1InjectAgentMessage": ".types",
    "AgentV1InjectAgentMessageParams": ".requests",
    "AgentV1InjectUserMessage": ".types",
    "AgentV1InjectUserMessageParams": ".requests",
    "AgentV1InjectionRefused": ".types",
    "AgentV1InjectionRefusedParams": ".requests",
    "AgentV1KeepAlive": ".types",
    "AgentV1KeepAliveParams": ".requests",
    "AgentV1PromptUpdated": ".types",
    "AgentV1PromptUpdatedParams": ".requests",
    "AgentV1ReceiveFunctionCallResponse": ".types",
    "AgentV1ReceiveFunctionCallResponseParams": ".requests",
    "AgentV1SendFunctionCallResponse": ".types",
    "AgentV1SendFunctionCallResponseParams": ".requests",
    "AgentV1Settings": ".types",
    "AgentV1SettingsAgent": ".types",
    "AgentV1SettingsAgentContext": ".types",
    "AgentV1SettingsAgentContextMessagesItem": ".types",
    "AgentV1SettingsAgentContextMessagesItemContent": ".types",
    "AgentV1SettingsAgentContextMessagesItemContentParams": ".requests",
    "AgentV1SettingsAgentContextMessagesItemContentRole": ".types",
    "AgentV1SettingsAgentContextMessagesItemFunctionCalls": ".types",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItem": ".types",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams": ".requests",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsParams": ".requests",
    "AgentV1SettingsAgentContextMessagesItemParams": ".requests",
    "AgentV1SettingsAgentContextParams": ".requests",
    "AgentV1SettingsAgentListen": ".types",
    "AgentV1SettingsAgentListenParams": ".requests",
    "AgentV1SettingsAgentListenProvider": ".types",
    "AgentV1SettingsAgentListenProviderParams": ".requests",
    "AgentV1SettingsAgentListenProviderV1": ".types",
    "AgentV1SettingsAgentListenProviderV1Params": ".requests",
    "AgentV1SettingsAgentListenProviderV2": ".types",
    "AgentV1SettingsAgentListenProviderV2Params": ".requests",
    "AgentV1SettingsAgentListenProvider_V1": ".types",
    "AgentV1SettingsAgentListenProvider_V1Params": ".requests",
    "AgentV1SettingsAgentListenProvider_V2": ".types",
    "AgentV1SettingsAgentListenProvider_V2Params": ".requests",
    "AgentV1SettingsAgentParams": ".requests",
    "AgentV1SettingsAgentSpeak": ".types",
    "AgentV1SettingsAgentSpeakParams": ".requests",
    "AgentV1SettingsAgentThink": ".types",
    "AgentV1SettingsAgentThinkParams": ".requests",
    "AgentV1SettingsApplied": ".types",
    "AgentV1SettingsAppliedParams": ".requests",
    "AgentV1SettingsAudio": ".types",
    "AgentV1SettingsAudioInput": ".types",
    "AgentV1SettingsAudioInputEncoding": ".types",
    "AgentV1SettingsAudioInputParams": ".requests",
    "AgentV1SettingsAudioOutput": ".types",
    "AgentV1SettingsAudioOutputEncoding": ".types",
    "AgentV1SettingsAudioOutputParams": ".requests",
    "AgentV1SettingsAudioParams": ".requests",
    "AgentV1SettingsFlags": ".types",
    "AgentV1SettingsFlagsParams": ".requests",
    "AgentV1SettingsParams": ".requests",
    "AgentV1SpeakUpdated": ".types",
    "AgentV1SpeakUpdatedParams": ".requests",
    "AgentV1UpdatePrompt": ".types",
    "AgentV1UpdatePromptParams": ".requests",
    "AgentV1UpdateSpeak": ".types",
    "AgentV1UpdateSpeakParams": ".requests",
    "AgentV1UserStartedSpeaking": ".types",
    "AgentV1UserStartedSpeakingParams": ".requests",
    "AgentV1Warning": ".types",
    "AgentV1WarningParams": ".requests",
    "AgentV1Welcome": ".types",
    "AgentV1WelcomeParams": ".requests",
    "settings": ".settings",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentV1AgentAudioDone",
    "AgentV1AgentAudioDoneParams",
    "AgentV1AgentStartedSpeaking",
    "AgentV1AgentStartedSpeakingParams",
    "AgentV1AgentThinking",
    "AgentV1AgentThinkingParams",
    "AgentV1ConversationText",
    "AgentV1ConversationTextParams",
    "AgentV1ConversationTextRole",
    "AgentV1Error",
    "AgentV1ErrorParams",
    "AgentV1FunctionCallRequest",
    "AgentV1FunctionCallRequestFunctionsItem",
    "AgentV1FunctionCallRequestFunctionsItemParams",
    "AgentV1FunctionCallRequestParams",
    "AgentV1InjectAgentMessage",
    "AgentV1InjectAgentMessageParams",
    "AgentV1InjectUserMessage",
    "AgentV1InjectUserMessageParams",
    "AgentV1InjectionRefused",
    "AgentV1InjectionRefusedParams",
    "AgentV1KeepAlive",
    "AgentV1KeepAliveParams",
    "AgentV1PromptUpdated",
    "AgentV1PromptUpdatedParams",
    "AgentV1ReceiveFunctionCallResponse",
    "AgentV1ReceiveFunctionCallResponseParams",
    "AgentV1SendFunctionCallResponse",
    "AgentV1SendFunctionCallResponseParams",
    "AgentV1Settings",
    "AgentV1SettingsAgent",
    "AgentV1SettingsAgentContext",
    "AgentV1SettingsAgentContextMessagesItem",
    "AgentV1SettingsAgentContextMessagesItemContent",
    "AgentV1SettingsAgentContextMessagesItemContentParams",
    "AgentV1SettingsAgentContextMessagesItemContentRole",
    "AgentV1SettingsAgentContextMessagesItemFunctionCalls",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItem",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItemParams",
    "AgentV1SettingsAgentContextMessagesItemFunctionCallsParams",
    "AgentV1SettingsAgentContextMessagesItemParams",
    "AgentV1SettingsAgentContextParams",
    "AgentV1SettingsAgentListen",
    "AgentV1SettingsAgentListenParams",
    "AgentV1SettingsAgentListenProvider",
    "AgentV1SettingsAgentListenProviderParams",
    "AgentV1SettingsAgentListenProviderV1",
    "AgentV1SettingsAgentListenProviderV1Params",
    "AgentV1SettingsAgentListenProviderV2",
    "AgentV1SettingsAgentListenProviderV2Params",
    "AgentV1SettingsAgentListenProvider_V1",
    "AgentV1SettingsAgentListenProvider_V1Params",
    "AgentV1SettingsAgentListenProvider_V2",
    "AgentV1SettingsAgentListenProvider_V2Params",
    "AgentV1SettingsAgentParams",
    "AgentV1SettingsAgentSpeak",
    "AgentV1SettingsAgentSpeakParams",
    "AgentV1SettingsAgentThink",
    "AgentV1SettingsAgentThinkParams",
    "AgentV1SettingsApplied",
    "AgentV1SettingsAppliedParams",
    "AgentV1SettingsAudio",
    "AgentV1SettingsAudioInput",
    "AgentV1SettingsAudioInputEncoding",
    "AgentV1SettingsAudioInputParams",
    "AgentV1SettingsAudioOutput",
    "AgentV1SettingsAudioOutputEncoding",
    "AgentV1SettingsAudioOutputParams",
    "AgentV1SettingsAudioParams",
    "AgentV1SettingsFlags",
    "AgentV1SettingsFlagsParams",
    "AgentV1SettingsParams",
    "AgentV1SpeakUpdated",
    "AgentV1SpeakUpdatedParams",
    "AgentV1UpdatePrompt",
    "AgentV1UpdatePromptParams",
    "AgentV1UpdateSpeak",
    "AgentV1UpdateSpeakParams",
    "AgentV1UserStartedSpeaking",
    "AgentV1UserStartedSpeakingParams",
    "AgentV1Warning",
    "AgentV1WarningParams",
    "AgentV1Welcome",
    "AgentV1WelcomeParams",
    "settings",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CreateProjectDistributionCredentialsV1ResponseDistributionCredentials(UniversalBaseModel):
    distribution_credentials_id: str = pydantic.Field()
    """
    Unique identifier for the distribution credentials
    """

    provider: str = pydantic.Field()
    """
    The provider of the distribution service
    """

    comment: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional comment about the credentials
    """

    scopes: typing.List[str] = pydantic.Field()
    """
    List of permission scopes for the credentials
    """

    created: dt.datetime = pydantic.Field()
    """
    Timestamp when the credentials were created
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ThinkSettingsV1FunctionsItemEndpointParams(typing_extensions.TypedDict):
    """
    The Function endpoint to call. if not passed, function is called client-side
    """

    url: typing_extensions.NotRequired[str]
    """
    Endpoint URL
    """

    method: typing_extensions.NotRequired[str]
    """
    HTTP method
    """

    headers: typing_extensions.NotRequired[typing.Dict[str, str]]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentThinkModelsV1ResponseModelsItemThree(UniversalBaseModel):
    """
    Groq models
    """

    id: typing.Literal["openai/gpt-oss-20b"] = pydantic.Field(default="openai/gpt-oss-20b")
    """
    The unique identifier of the Groq model
    """

    name: str = pydantic.Field()
    """
    The display name of the model
    """

    provider: typing.Literal["groq"] = pydantic.Field(default="groq")
    """
    The provider of the model
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .shared_topics_results_topics_segments_item_topics_item import SharedTopicsResultsTopicsSegmentsItemTopicsItem


class SharedTopicsResultsTopicsSegmentsItem(UniversalBaseModel):
    text: typing.Optional[str] = None
    start_word: typing.Optional[float] = None
    end_word: typing.Optional[float] = None
    topics: typing.Optional[typing.List[SharedTopicsResultsTopicsSegmentsItemTopicsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.speak_v1flush_type import SpeakV1FlushType


class SpeakV1FlushParams(typing_extensions.TypedDict):
    type: SpeakV1FlushType
    """
    Message type identifier
    """



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .speak_v1clear import SpeakV1Clear
    from .speak_v1clear_type import SpeakV1ClearType
    from .speak_v1cleared import SpeakV1Cleared
    from .speak_v1cleared_type import SpeakV1ClearedType
    from .speak_v1close import SpeakV1Close
    from .speak_v1close_type import SpeakV1CloseType
    from .speak_v1flush import SpeakV1Flush
    from .speak_v1flush_type import SpeakV1FlushType
    from .speak_v1flushed import SpeakV1Flushed
    from .speak_v1flushed_type import SpeakV1FlushedType
    from .speak_v1metadata import SpeakV1Metadata
    from .speak_v1text import SpeakV1Text
    from .speak_v1warning import SpeakV1Warning
_dynamic_imports: typing.Dict[str, str] = {
    "SpeakV1Clear": ".speak_v1clear",
    "SpeakV1ClearType": ".speak_v1clear_type",
    "SpeakV1Cleared": ".speak_v1cleared",
    "SpeakV1ClearedType": ".speak_v1cleared_type",
    "SpeakV1Close": ".speak_v1close",
    "SpeakV1CloseType": ".speak_v1close_type",
    "SpeakV1Flush": ".speak_v1flush",
    "SpeakV1FlushType": ".speak_v1flush_type",
    "SpeakV1Flushed": ".speak_v1flushed",
    "SpeakV1FlushedType": ".speak_v1flushed_type",
    "SpeakV1Metadata": ".speak_v1metadata",
    "SpeakV1Text": ".speak_v1text",
    "SpeakV1Warning": ".speak_v1warning",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "SpeakV1Clear",
    "SpeakV1ClearType",
    "SpeakV1Cleared",
    "SpeakV1ClearedType",
    "SpeakV1Close",
    "SpeakV1CloseType",
    "SpeakV1Flush",
    "SpeakV1FlushType",
    "SpeakV1Flushed",
    "SpeakV1FlushedType",
    "SpeakV1Metadata",
    "SpeakV1Text",
    "SpeakV1Warning",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1settings_agent_context_messages_item_function_calls_function_calls_item import (
    AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItem,
)


class AgentV1SettingsAgentContextMessagesItemFunctionCalls(UniversalBaseModel):
    """
    Client-side or server-side function call request and response as part of the conversation history
    """

    type: typing.Literal["History"] = "History"
    function_calls: typing.List[AgentV1SettingsAgentContextMessagesItemFunctionCallsFunctionCallsItem] = (
        pydantic.Field()
    )
    """
    List of function call objects
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1ReceiveFunctionCallResponseParams(typing_extensions.TypedDict):
    """
    Function call response message used bidirectionally:

    • **Client → Server**: Response after client executes a function
      marked as client_side: true
    • **Server → Client**: Response after server executes a function
      marked as client_side: false

    The same message structure serves both directions, enabling a unified
    interface for function call responses regardless of execution location.
    """

    type: typing.Literal["FunctionCallResponse"]
    """
    Message type identifier for function call responses
    """

    id: typing_extensions.NotRequired[str]
    """
    The unique identifier for the function call.
    
    • **Required for client responses**: Should match the id from
      the corresponding `FunctionCallRequest`
    • **Optional for server responses**: Server may omit when responding
      to internal function executions
    """

    name: str
    """
    The name of the function being called
    """

    content: str
    """
    The content or result of the function call
    """
